<!-- #include file="classes_session.asp"-->
<!-- #include file="classes_basket.asp"-->
<%
'===============================================
' CactuShop ASP Shopping Cart
' 1999-2007 Cactusoft International FZ-LLC
' www.cactusoft.com
'===============================================
' All rights reserved.							
' Use of this code is covered by the terms and	
' conditions in the license agreement. No		
' unauthorized duplication or distribution is	
' permitted. Cactusoft's copyright notices must	
' remain in the ASP sections of the code.		
'===============================================

'-----------------------------------------------
'CURRENCYDATA CLASS
'Contains details on a currency record, and 
'functions for currency display
'-----------------------------------------------
'Consts for default formats
Const DEFAULT_FORMAT = "[symbol] [value]"
Const DEFAULT_ISO_FORMAT = "[iso] [value]"

'Holds currency information
Class CurrencyData
	Public ID
	Public Symbol
	Public ISOCode
	Public ExchangeRate
	Public HasDecimals
	Public Name
	Public DecimalPoint
	
	'Currency format. For backwards-compatability,
	'if now format is provided, then it uses the default
	'format defined in the const above. 
	Private m_format
	Public Property Get Format
		If m_format = "" then
			Format = DEFAULT_FORMAT
		Else
			Format = m_format
		End If
	End Property
	
	Public Property Let Format(newformat)
		m_format = newformat & ""
	End Property
	
	'Same for iso format
	Private m_isoformat
	Public Property Get IsoFormat
		If m_isoformat = "" then
			IsoFormat = DEFAULT_ISO_FORMAT
		Else
			IsoFormat = m_isoformat
		End If
	End Property
	
	Public Property Let IsoFormat(newisoformat)
		m_isoformat = newisoformat & ""
	End Property

	'Loads in the currency data from the recordset
	Public Sub Load(objRS)
		ID = objRS("CUR_ID")
		Symbol = objRS("CUR_Symbol")
		ISOCode = objRS("CUR_ISOCode")
		ExchangeRate = objRS("CUR_ExchangeRate")
		HasDecimals = (objRS("CUR_HasDecimals") = "y")
		Name = objRS("CUR_Name" & CStr(numLanguageID))
		Format = objRS("CUR_Format")
		IsoFormat = objRS("CUR_IsoFormat")
		DecimalPoint = objRS("CUR_DecimalPoint")
	End Sub
	
	Private Function FormatValue(numAmount, blnConvert, strDecimal)
		'Take local copy of amount, convert it required
		numLocalAmount = NumSafe(numAmount)
		If blnConvert then numLocalAmount = Convert(numLocalAmount)
		numLocalAmount = SafeRound(numLocalAmount + 0.00001, 2)
		
		'Format the numerical value
		If Not HasDecimals then
			'No decimals
			numLocalAmount = CStr(SafeRound(numLocalAmount, 0))
		Else
			'Get whether the amount is negative - if it is, pos it for now
			'and change it back later
			If numLocalAmount < 0 then
				blnNegative = true
				numLocalAmount = abs(numLocalAmount)
			End If
			
			'Convert to currency format
			numIntegerPart = Int(numLocalAmount)
			strDecimalPart = Mid(FormatNumber(numLocalAmount - numIntegerPart, 2, false), 2)
			
			'Change back to negative if required
			If blnNegative then
					numLocalAmount = "-" & CStr(numIntegerPart & strDecimal & strDecimalPart)
			Else
				numLocalAmount = CStr(numIntegerPart & strDecimal & strDecimalPart)
			end if
		End If	
		FormatValue = numLocalAmount
	End Function		
	
	'Converts value by the currency exchange rate
	Public Function Convert(numAmount)
		Convert = NumSafe(numAmount) * ExchangeRate
	End Function
	
	
	'Process data in to a template. Currency templates 
	'support 3 tags - [iso], [symbol] and [value]
	Private Function Template(strTemplate, strAmount)
		Template = Replace(Replace(Replace(strTemplate, "[iso]", ISOCode), "[symbol]", Symbol), "[value]", strAmount)
	End Function
	
	'Returns a string for display
	Public Function Display(numAmount, blnConvert, blnIsoFormat)
		Display = Template(IIf(blnIsoFormat, ISOFormat, Format), DisplayWithoutSymbol(numAmount, blnConvert))
	End Function
	
		
	'Returns a string for display without a currency symbol
	Public Function DisplayWithoutSymbol(numAmount, blnConvert)
		DisplayWithoutSymbol = FormatValue(numAmount, blnConvert, DecimalPoint)
	End Function
	
	'Most gateways expect a decimal point. This overrides and sends a decimal.
	Public Function DisplayForGateway(numAmount)
		DisplayForGateway = FormatValue(numAmount, false, ".")
	End Function
	
	
End Class


'-----------------------------------------------
'BREADCRUMB TRAIL
'Holds information for a breadcrumb trail and
'writes out the result

'LS 150, 151, 152, 157, 158, 159, 779, 1782
'-----------------------------------------------
Class BreadCrumb
	Public Name
	Public URL	
End Class

Const BREADCRUMB_STEP = 10
Class BreadCrumbTrail
	
	Private MaxIndex
	
	Private m_breadCrumbs()
	Private m_seperator
	Private m_style
	Private m_pageHistory
	Private m_parents
	Private m_searchStartRecord
	Private m_categoryID
	
	Public Property Get Count
		Count = MaxIndex + 1
	End Property	
	
	Public Property Get PageHistory
		PageHistory = m_pageHistory
	End Property
	
	Public Property Let PageHistory(value)
		m_pageHistory = value
	End Property
	
	Public Property Get SearchStartRecord
		SearchStartRecord = m_searchStartRecord
	End Property
	
	Public Property Let SearchStartRecord(value)
		m_searchStartRecord = value
	End Property
	
	Public Property Get Parents
		Parents = m_parents
	End Property
	
	Public Property Let Parents(value)
		m_parents = value
	End Property
	
	Public Property Get ItemName(index)
		ItemName = m_breadCrumbs(index).Name
	End Property
	
	'Initialises the array with 10 items
	Private Sub Class_Initialize()
		Redim m_breadCrumbs(BREADCRUMB_STEP)
		MaxIndex = -1
		m_seperator = "&#187; "
		m_style = "breadcrumbtrail"
		m_pageHistory = ListSafe(DualRequest("strPageHistory"), "category,basket,search,related,wishlist,promotion,compare", "home")
		m_parents = DualRequest("strParents") 
		m_searchStartRecord = NumSafe(DualRequest("numSearchStartRecord"))
	End Sub	
	
	
	'Adds a new crumb to the trail, building a full URL
	Private Sub Add(strName, strURL, strQuerystring)
		'Create the new crumb
		If strURL = "" then
			strFullURL = ""
			
		ElseIf left(strURL, 10) = "javascript" then
			strFullURL = strURL
		
		Else
			strFullURL = strTemplateShopFolder & strURL & "?" & objCactuSession.QS & strQuerystring
		End If
		Call AddBreadCrumb(strName, strFullURL)
	End Sub
	
	'Adds a new category breadcrumb
	Private Sub AddCategoryCrumb(numCategoryID, strCategoryName, aryParentIDs, aryParentNames, numPage)
		Set objCrumbURL = New DynamicLinks
		strURL = objCrumbURL.GetCategoryLink(numCategoryID, strCategoryName, aryParentIDs, aryParentNames, numPage)
		Call AddBreadCrumb(strCategoryName, strURL)
	End Sub
	
	'Adds breadcrumb
	Private Sub AddBreadCrumb(strName, strURL)
		'Increase the array if required and add
		MaxIndex = MaxIndex + 1
		If UBound(m_breadCrumbs) < MaxIndex then
			Redim Preserve m_breadCrumbs(MaxIndex + BREADCRUMB_STEP)
		End If
		
		'Add new crumb
		Set m_breadCrumbs(MaxIndex) = New BreadCrumb
		m_breadCrumbs(MaxIndex).Name = strName
		m_breadCrumbs(MaxIndex).URL = strURL
	End Sub
	
	
	'Builds up the breadcrumb trail
	Public Sub Build(objRS, numCategoryID, strCategoryName, strProductName)
		
		m_categoryID = NumSafe(numCategoryID)
		If m_categoryID <> 0 and m_pageHistory <> "search" then m_pageHistory = "category"
		select case m_pageHistory
			case "category":	Call Add(GetString("ContentText_Categories"), "prodtype.asp", "")
			case "basket":		Call Add(GetString("ContentText_Basket"), "basket.asp", "")
			case "search":		Call Add(GetString("ContentText_Search"), "search.asp", "")
								Call Add(GetString("ContentText_SearchResults"), "search.asp", "numSearchStartRecord=" & m_searchStartRecord)
			case "related":		Call Add(GetString("ContentText_RelatedProduct"), "javascript:history.back()", "")
			case "wishlist":	Call Add(GetString("PageTitle_WishList"), "wishlist.asp", "")
			case "promotion":	Call Add(GetString("ContentText_Promotion"), "javascript:history.back()", "")
			Case "compare":		Call Add(GetString("ContentText_ViewCompareButton"), "compare.asp", "")
			case Else:			Call Add(GetString("ContentText_Home"), "default.asp", "")
		end select
		
		'Add on any categories we've been through
		If m_parents <> "" then
			'Set defaults
			numLastParentID = 0
			strParentIDs = ""
			strParentNames = ""
			
			'Loop around parents
			aryParents = Split(m_parents, ",")
			If Ubound(aryParents) > 30 then aryParents = Split("0", ",")			'Protect against querystring hacks for really long loops
			For Each strParentID in aryParents
				numParentID = NumSafe(strParentID)
				If numParentID > 0 and numParentID <> numCategoryID then
					'If it's in the DB, add to trail
					strQuery = "SELECT CAT_Name" & numLanguageID & " FROM tblCactuShop" & TABLE_PREFIX & "Categories c LEFT JOIN tblCactuShop" & TABLE_PREFIX & "CategoryHierachy ch ON c.CAT_ID = ch.CH_ChildID WHERE c.CAT_ID=" & numParentID & IIf(numLastParentID = 0, "", " AND c.CAT_Live='y' AND c.CAT_CustomerGroupID IN (0," & DB_CG_ID & ") AND ch.CH_ParentID=" & numLastParentID)
					Call ExecuteRS(strQuery, objRS)
					If Not (objRS.BOF And objRS.EOF) Then
						'Add to trail
						strParentName = objRS("CAT_Name" & numLanguageID)
						Call AddCategoryCrumb(numParentID, strParentName, Split(strParentIDs, ","), Split(strParentNames, chr(0)), 1)
						
						'Keep tabs on the parents we've done
						strParentIDs = IIf(strParentIDs = "", numParentID, strParentIDs & "," & numParentID)
						strParentNames = IIf(strParentNames = "", strParentName, strParentNames & chr(0) & strParentName)
						
						numLastParentID = numParentID
					End If
					objRS.Close
				End If
			Next
		End If
		
		If numCategoryID <> "" and numCategoryID & "" <> "0" then
			'If we've got a product, link this category
			If strProductName <> "" then
				Call Add(strCategoryName, "prodtype.asp", BaseQS & IIf(m_parents <> "", "strParents=" & m_parents & "&amp;", "") & "CAT_ID=" & m_categoryID)
			Else
				Call Add(strCategoryName, "", "")
			End If
		End If
		
		'Add the product
		If strProductName <> "" then
			Call Add(strProductName, "", "")
		end if
	
	End Sub
	
	'Returns the querystring part for the history links
	Public Function QS
		QS = BaseQS & IIf(m_parents <> "", "strParents=" & m_parents & "&amp;", "")
	End Function
	
	Private Function BaseQS
		BaseQS = "strPageHistory=" & m_pageHistory & "&amp;numSearchStartRecord=" & m_searchStartRecord & "&amp;"
	End Function
	
	Public Function Form
		Form =  "<input type=""hidden"" name=""strPageHistory"" value=""" & m_pageHistory & """ />" & vbcrlf &_
				"<input type=""hidden"" name=""numSearchStartRecord"" value=""" & m_searchStartRecord & """ />" & vbcrlf
		If m_parents <> "" then Form = Form & "<input type=""hidden"" name=""strParents"" value=""" & m_parents & """ />" & vbcrlf
	End Function
	
	'The deeper functions add on the current category. This is for going
	''deeper' in the structure (a subcat or a product)
	Public Function DeeperQS
		DeeperQS = BaseQS & "strParents=" & IIf(m_parents = "", m_categoryID, m_parents & IIf(m_categoryID = "", "", "," & m_categoryID)) & "&amp;"
	End Function
			
	Public Function DeeperForm
		DeeperForm =  "<input type=""hidden"" name=""strPageHistory"" value=""" & m_pageHistory & """ />" & vbcrlf &_
					  "<input type=""hidden"" name=""numSearchStartRecord"" value=""" & m_searchStartRecord & """ />" & vbcrlf &_
					  "<input type=""hidden"" name=""strParents"" value=""" & IIf(m_parents = "", m_categoryID, m_parents & IIf(m_categoryID = "", "", "," & m_categoryID)) & """ />" & vbcrlf
	End Function
		
	
	'Return HTML presentation of the trail
	Public Function ToHTML()
		For i = 0 to MaxIndex
			strSeperator = IIf(i = 0, "", m_seperator)
			If m_breadCrumbs(i).URL = "" then
				strStartHTML = strStartHTML & "<ul><li" & IIf(i = 0, " class=""first""", "") & ">" & strSeperator & m_breadCrumbs(i).Name & vbcrlf
			Else
				strStartHTML = strStartHTML & "<ul><li" & IIf(i = 0, " class=""first""", "") & ">" & strSeperator & "<a href=""" & m_breadCrumbs(i).URL & """>" & m_breadCrumbs(i).Name & "</a>" & vbcrlf
			End If
			strEndHTML = strEndHTML & "</li></ul>" & vbcrlf
		Next
		ToHTML = "<div class=""" & m_style & """>" & vbcrlf & strStartHTML & strEndHTML & "</div>" & vbcrlf
	End Function
	
End Class








%>
